# Astron
---


### Note: SI Units used throughout library
```
- Time: s (seconds)
- Distance: m (meters)
- Mass: kg (kilograms)
```


# Ideas
<!-- - Escape velocity display -->
<!-- - Thrusters -->
<!-- - Fail on spacecraft touching planet -->
<!-- - Background -->
<!-- - Attempt counter -->
<!-- - Level stages -->
- .exe compile + launch
<!-- - score system -->
<!-- - startup splash screen -->
- score